( cd usr/lib ; rm -rf libt1.so.5 )
( cd usr/lib ; ln -sf libt1.so.5.1.0 libt1.so.5 )
( cd usr/lib ; rm -rf libt1.so )
( cd usr/lib ; ln -sf libt1.so.5.1.0 libt1.so )
( cd usr/lib ; rm -rf libt1x.so.5 )
( cd usr/lib ; ln -sf libt1x.so.5.1.0 libt1x.so.5 )
( cd usr/lib ; rm -rf libt1x.so )
( cd usr/lib ; ln -sf libt1x.so.5.1.0 libt1x.so )
